
# Label templates

![](../../../images/finalpics-192.jpg)*Labeling your samples, original design by Maria Viftrup (2017), modified and photographed by Loes Bogers, 2020*

As you start to create your material experiments, you might want to organize the way you archive and/or showcase them. Following the example of the Material Archive at TextileLab Waag, it's a very activating gesture to include a summarized version of the recipe on the label, to indicate these are open-source recipes. 

These labels were adapted to include additional information to acknowledge and reference others, and describing changes made to the original, to add some sustainability info, and also describe what the material is based on. The title can be very descriptive, and comparative (like "banana clay"), but it is also useful see right away the origins of the core component and how it was sourced (which for banana clay would be: fruit waste). 

##Information to put on the labels

A nice systematic way of growing your archive is by starting simple variations on existing recipes, e.g. by changing the amounts, adding or substituting one ingredient, etcetera. 

**Title**

Think of a short, descriptive title, maybe even comparing it to materials it is similar to. 

**[Core]-based?**

Here you can what is the main constituent material to help describe what kind of material this is and how its main ingredient has been sourced. This is not a hard classification, but is supposed to provide a meaningful descriptor to help place the material (which the title alone might not be able to do). 

For example, a bioplastic may be *gelatine-based*, or *agar-based*, or *starch-based* (or a combination). Fish leather is *animal-based*, whereas a mango leather would be *plant-based*, or perhaps even based on fruit waste. Dyes or inks are usually classified accordig to their solvent: e.g. *alcohol-based* or *water-based* because it says something about how they might be used. Whereas pure pigment (powders, or pigments grown on silk like the Serratia Marcescens recipe could be considered *microbial*. 

Some examples: 

- animal-based (fish leather)
- gelatine-based (bioplastics with gelatine)
- plant-based (cotton)
- based on algae (alginate and agar plastics)
- food waste (clay from banana peels)
- natural waste (withered flower paper)
- plastic waste (recycled PLA)
- microbial (e.g. kombucha, bacterial dye)
- fungal (e.g. mycelium, is not in the 25 recipes listed here for now)
- alcohol-based (red cabbage ink with alcohol as the solvent)
- water-based (dyes made by boiling dye stuff in water)

**Renewable/reusable/compostable?**

A renewable material is a material that can replenish itself naturally on a human timescale. So plants, bacteria and fungi: definitely. Trees? Not really. Petroleum? Definitely not

A material is reusable if you can reshape it without loosing its qualities. For example: PLA can be remelted in such a way, and alum crystals can be redissolved and formed again without relatively little additional energy. 

A material is compostable if it can be turned into a fertilizer (a compound that is *beneficial* for plant growth within 90 days. Ideally, it is suitable for home-composting. Which means that it does not require industrial composting facilities to compost, but you can do it yourself under uncontrolled conditions. 

**Ingredients/making procedure**

Keep it short and sweet, and make sure you refer to the extended recipe that can be accessed online (see also "variations on a source recipe".)

**This is a variation on:**
The labels ask you to state which recipe is the "source" recipe, and how you are making variations on it. Assuming that you will start off by coming up with variations on the recipes listed here but you can also point to another recipe (use the QR code for quick access). 

**URL & QR code**

Put the URL to the online recipe in the box on the top left, and/or generate a QR code for that url and add it on the label for easy access on mobile phones. You can find [free QR code generators](https://www.qr-code-generator.com) online. Use short URLs if possible, you can shorten URLs with for example [bit.ly](https://app.bitly.com).

**Optional: customize with your logo & website**

Use the top right box and text field to customize the label by adding your lab's logo and url if you wish. 

**The small letters!**

Don't forget to fill out your details and the date of fabrication at the bottom of the label. 


![](../../../images/finalpics-191.jpg)*Labeling your samples, Loes Bogers, 2020*

## Printing and assembling

All these labels can be printed on regular office printers that can print on heavier paper, like A4, 160 or 210 grams/m2. Check what your printer allows. But don't forget to put your info before printing:

-  labels can be edited InDesign or Acrobat Pro (for now). Only include items that are fully cured and/or dried. 
-  Export the labels for print, and include crop marks for cutting
-  Print the labels on 160 or 210 grams/m2 paper
-  Cut along the crop marks to trim off the edges
-  Use strong double-sided tape to attach a strong label with a hole to it if you wish to hang them. Designs for a display system will be added here at a later stage, or design your own.

The label designs were originally created by [Maria Viftrup](https://viftrup.com/textilelab) for TextileLab Waag in Amsterdam, modified by Loes Bogers in April 2020 with permission by Waag. The font used is Calibri light. 

### Large labels 

These labels are 21 x 20 cm (WxH)

[InDesign file for large labels](./label_large.indd)

[PDF file for large labels](./label_large.pdf)

### Medium labels

These labels are 15 x 14.2 cm (WxH)

[InDesign file for large labels](./label_medium.indd)

[PDF file for large labels](./label_medium.pdf)

### Small labels 

These labels are 10.5 x 10 cm (WxH)

[InDesign file for large labels](./label_small.indd)

[PDF file for large labels](./label_small.pdf)



